@@ -43,12 +43,13 @@ describe 'horizon' do
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :servername     => 'some.host.tld',
-          :listen_ssl     => false,
-          :wsgi_processes => facts[:os_workers],
-          :wsgi_threads   => '1',
-          :extra_params   => {},
-          :redirect_type  => 'permanent',
+          :servername        => 'some.host.tld',
+          :listen_ssl        => false,
+          :wsgi_processes    => facts[:os_workers],
+          :wsgi_threads      => '1',
+          :extra_params      => {},
+          :redirect_type     => 'permanent',
+          :access_log_format => false,
         })
       end
 
@@ -64,7 +65,7 @@ describe 'horizon' do
           'HORIZON_CONFIG["images_panel"] = "legacy"',
           "SECRET_KEY = 'elj1IWiLoWHgcyYxFVLj7cM5rGOOxWl0'",
           'OPENSTACK_KEYSTONE_URL = "http://127.0.0.1:5000"',
-          'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "_member_"',
+          'OPENSTACK_KEYSTONE_DEFAULT_ROLE = "member"',
           "    'can_set_mount_point': True,",
           "    'can_set_password': False,",
           "    'enable_distributed_router': False,",
@@ -291,13 +292,15 @@ describe 'horizon' do
 
     context 'with custom wsgi options' do
       before do
-        params.merge!( :wsgi_processes => '30',
-                       :wsgi_threads   => '5' )
+        params.merge!( :wsgi_processes    => '30',
+                       :wsgi_threads      => '5',
+                       :access_log_format => 'common' )
       end
 
       it { should contain_class('horizon::wsgi::apache').with(
-        :wsgi_processes => '30',
-        :wsgi_threads   => '5',
+        :wsgi_processes    => '30',
+        :wsgi_threads      => '5',
+        :access_log_format => 'common',
       )}
     end
 
